@@ -2,16 +2,16 @@
 import sys
 
 
-sys.path.append('C:/Users/jrish/work/python-sdk/skylark_ai/skylark')
-print(sys.path)
+# sys.path.append('C:/Users/jrish/work/python-sdk/skylark_ai')
+# print(sys.path)
 
-from core.clients import Service
-from core.face_mask_stream import FaceMaskStreamClient
-from core.face_detect_stream import FaceDetectStreamClient
-from core.weapon_detection_stream import WeaponDetectionStreamClient
-from core.facial_landmark_stream import FacialLandmarkStream
-from core.lie_detection_stream import LieDetectionStreamClient
-from core.night_day_stream import NightDayStreamClient
+from skylark.core.clients import Service
+from skylark.core.face_mask_stream import FaceMaskStreamClient
+from skylark.core.face_detect_stream import FaceDetectStreamClient
+from skylark.core.weapon_detection_stream import WeaponDetectionStreamClient
+from skylark.core.facial_landmark_stream import FacialLandmarkStream
+from skylark.core.lie_detection_stream import LieDetectionStreamClient
+from skylark.core.night_day_stream import NightDayStreamClient
 import time
 
 
