@@ -1,4 +1,4 @@
-from constants.constants import WEBSOCKET_AUTH_API
+from skylark.constants.constants import WEBSOCKET_AUTH_API
 import requests
 import socket
 
